.. _python_setuptools_module:

:mod:`fabtools.python_setuptools`
---------------------------------

.. automodule:: fabtools.python_setuptools
    :members:

    .. seealso:: :ref:`python_module` and :ref:`require_python_module`
